PgDateTime class final
A wrapper for values with the Postgres timestamp without timezone and
timestamp with timezone types.
We can't use DateTime directly because drift expects to store them as unix timestamp or text.
Constructors
- PgDateTime(DateTime dateTime)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDateTime(
) → DateTime -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override