PgTypes class final
Provides custom types to enable the use of Postgres-specific types in drift databases.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
date
→ const CustomSqlType<
PgDate> -
The
datetype in Postgres. -
interval
→ const CustomSqlType<
Duration> -
The
intervaltype in Postgres. -
json
→ const CustomSqlType<
Object> -
The
jsontype in Postgres. -
jsonb
→ const CustomSqlType<
Object> -
The
jsonbtype in Postgres. -
point
→ const CustomSqlType<
PgPoint> -
The
pointtype in Postgres. -
timestampNoTimezone
→ const CustomSqlType<
PgDateTime> -
The
timestamp without time zonetype in Postgres. -
uuid
→ const CustomSqlType<
UuidValue> -
The
UUIDtype in Postgres.